;; Generated package description from rnc-mode.el  -*- no-byte-compile: t; lexical-binding:t -*-
(define-package "rnc-mode" "0.4.0.20260610.0" "Emacs mode to edit Relax-NG Compact files" 'nil :commit "2ffd0775392b6f5efd82c775f3a1cb5bea8c917d" :url "https://elpa.gnu.org/packages/rnc-mode.html" :authors '(("Stefan Monnier" . "monnier@iro.umontreal.ca")) :maintainer '("Stefan Monnier" . "monnier@iro.umontreal.ca") :keywords '("xml" "relaxng"))
